@@ -3,8 +3,9 @@ package Class::Usul::File;
 use namespace::autoclean;
 
 use Class::Usul::Constants qw( EXCEPTION_CLASS TRUE );
-use Class::Usul::Functions qw( arg_list create_token is_arrayref io throw );
-use Class::Usul::Types     qw( BaseType );
+use Class::Usul::Functions qw( arg_list create_token is_arrayref io
+                               merge_attributes throw );
+use Class::Usul::Types     qw( ConfigProvider Locker Logger );
 use English                qw( -no_match_vars );
 use File::DataClass::Schema;
 use File::Spec::Functions  qw( catfile );
@@ -12,9 +13,23 @@ use Scalar::Util           qw( blessed );
 use Unexpected::Functions  qw( Unspecified );
 use Moo;
 
-# Private attributes
-has '_usul' => is => 'ro', isa => BaseType, handles => [ 'config' ],
-   init_arg => 'builder', required => TRUE, weak_ref => TRUE;
+# Public attributes
+has 'config' => is => 'ro', isa => ConfigProvider, required => TRUE;
+
+has 'lock'   => is => 'ro', isa => Locker, required => TRUE;
+
+has 'log'    => is => 'ro', isa => Logger, required => TRUE;
+
+# Construction
+around 'BUILDARGS' => sub {
+   my ($orig, $self, @args) = @_; my $attr = $orig->( $self, @args );
+
+   my $builder = delete $attr->{builder} or return $attr;
+
+   merge_attributes $attr, $builder, {}, [ 'config', 'lock', 'log' ];
+
+   return $attr;
+};
 
 # Public methods
 sub data_dump {
@@ -29,11 +44,11 @@ sub data_dump {
 sub data_load {
    my ($self, @args) = @_; my $args = arg_list @args; my $attr = {};
 
-   defined $args->{storage_class}
-       and $attr->{storage_class} = delete $args->{storage_class};
+   exists $args->{storage_class} and defined $args->{storage_class}
+      and $attr->{storage_class} = delete $args->{storage_class};
 
-   defined $args->{arrays}
-       and $attr->{storage_attributes}->{force_array} = $args->{arrays};
+   exists $args->{arrays} and defined $args->{arrays}
+      and $attr->{storage_attributes}->{force_array} = $args->{arrays};
 
   (is_arrayref $args->{paths} and defined $args->{paths}->[ 0 ])
       or throw Unspecified, args => [ 'paths' ];
@@ -44,7 +59,9 @@ sub data_load {
 sub dataclass_schema {
    my ($self, @args) = @_; my $attr = arg_list @args;
 
-   if (blessed $self) { $attr->{builder} = $self->_usul }
+   if (blessed $self) {
+      merge_attributes $attr, $self, {}, [ 'lock', 'log', 'tempdir' ];
+   }
    else { $attr->{cache_class} = 'none' }
 
    $attr->{storage_class} //= 'Any';
@@ -53,7 +70,7 @@ sub dataclass_schema {
 }
 
 sub delete_tmp_files {
-   return io( $_[ 1 ] || $_[ 0 ]->tempdir )->delete_tmp_files;
+   return io( $_[ 1 ] // $_[ 0 ]->tempdir )->delete_tmp_files;
 }
 
 sub tempdir {
@@ -61,7 +78,7 @@ sub tempdir {
 }
 
 sub tempfile {
-   return io( $_[ 1 ] || $_[ 0 ]->tempdir )->tempfile;
+   return io( $_[ 1 ] // $_[ 0 ]->tempdir )->tempfile;
 }
 
 sub tempname {
@@ -70,7 +87,7 @@ sub tempname {
    while (not $path or -f $path) {
       my $file = sprintf '%6.6d%s', $PID, (substr create_token, 0, 4);
 
-      $path = catfile( $dir || $self->tempdir, $file );
+      $path = catfile( $dir // $self->tempdir, $file );
    }
 
    return $path;
@@ -82,6 +99,8 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 Name
 
 Class::Usul::File - Data loading and dumping
@@ -99,9 +118,34 @@ Class::Usul::File - Data loading and dumping
 Provides data loading and dumping methods, Also temporary file methods
 and directories instantiated using the L<Class::Usul::Config> object
 
+=head1 Configuration and Environment
+
+Defined the following attributes;
+
+=over 3
+
+=item C<config>
+
+A required instance of type C<ConfigProvider>
+
+=item C<lock>
+
+A required instance of type C<Locker>
+
+=item C<log>
+
+A required instance of type C<Logger>
+
+=back
+
 =head1 Subroutines/Methods
 
-=head2 data_dump
+=head2 C<BUILDARGS>
+
+Extracts the required constructor attributes from the C<builder> attribute
+if it was supplied
+
+=head2 C<data_dump>
 
    $self->dump( @args );
 
@@ -109,7 +153,7 @@ Accepts either a list or a hash ref. Calls L</dataclass_schema> with
 the I<storage_class> attribute if supplied. Calls the
 L<dump|File::DataClass::Schema/dump> method
 
-=head2 data_load
+=head2 C<data_load>
 
    $hash_ref = $self->load( @args );
 
@@ -117,7 +161,7 @@ Accepts either a list or a hash ref. Calls L</dataclass_schema> with
 the I<storage_class> and I<arrays> attributes if supplied. Calls the
 L<load|File::DataClass::Schema/load> method
 
-=head2 dataclass_schema
+=head2 C<dataclass_schema>
 
    $f_dc_schema_obj = $self->dataclass_schema( $attrs );
 
@@ -125,20 +169,20 @@ Returns a L<File::DataClass::Schema> object. Object uses our
 C<exception_class>, no caching and no locking by default. Works as a
 class method
 
-=head2 delete_tmp_files
+=head2 C<delete_tmp_files>
 
    $self->delete_tmp_files( $dir );
 
 Delete this processes temporary files. Files are in the C<$dir> directory
 which defaults to C<< $self->tempdir >>
 
-=head2 tempdir
+=head2 C<tempdir>
 
    $temporary_directory = $self->tempdir;
 
 Returns C<< $self->config->tempdir >> or L<File::Spec/tmpdir>
 
-=head2 tempfile
+=head2 C<tempfile>
 
    $tempfile_obj = $self->tempfile( $dir );
 
@@ -146,7 +190,7 @@ Returns a L<File::Temp> object in the C<$dir> directory
 which defaults to C<< $self->tempdir >>. File is automatically deleted
 if the C<$tempfile_obj> reference goes out of scope
 
-=head2 tempname
+=head2 C<tempname>
 
    $pathname = $self->tempname( $dir );
 
@@ -158,10 +202,6 @@ L</delete_tmp_files> if it is called otherwise it will persist
 
 None
 
-=head1 Configuration and Environment
-
-None
-
 =head1 Dependencies
 
 =over 3
