@@ -35,20 +35,21 @@ use User::pwent;
 
 our @EXPORT_OK   = qw( abs_path app_prefix arg_list assert assert_directory
                        base64_decode_ns base64_encode_ns bsonid bsonid_time
-                       bson64id bson64id_time build canonicalise chain
-                       class2appdir classdir classfile create_token curry cwdp
-                       dash2under data_dumper digest distname elapsed emit
-                       emit_err emit_to ensure_class_loaded env_prefix
-                       escape_TT exception find_apphome find_source first_char
-                       fold fqdn fullname get_cfgfiles get_user hex2str
-                       home2appldir io is_arrayref is_coderef is_hashref
-                       is_member is_win32 list_attr_of loginid logname
-                       merge_attributes my_prefix nonblocking_write_pipe_pair
-                       pad prefix2class product socket_pair split_on__
-                       split_on_dash squeeze strip_leader sub_name sum symlink
-                       thread_id throw throw_on_error trim unescape_TT
+                       bson64id bson64id_time canonicalise class2appdir
+                       classdir classfile create_token cwdp dash2under
+                       data_dumper digest distname elapsed emit emit_err
+                       emit_to ensure_class_loaded env_prefix escape_TT
+                       exception find_apphome find_source first_char fqdn
+                       fullname get_cfgfiles get_user hex2str home2appldir io
+                       is_arrayref is_coderef is_hashref is_member is_win32
+                       list_attr_of loginid logname merge_attributes my_prefix
+                       nonblocking_write_pipe_pair pad prefix2class socket_pair
+                       split_on__ split_on_dash squeeze strip_leader sub_name
+                       symlink thread_id throw throw_on_error trim unescape_TT
                        untaint_cmdline untaint_identifier untaint_path
-                       untaint_string urandom uuid whiten zip );
+                       untaint_string urandom uuid whiten zip chain compose
+                       curry fold Y factorial fibonacci product sum );
+
 our %EXPORT_REFS =   ( assert => sub { ASSERT }, );
 our %EXPORT_TAGS =   ( all    => [ @EXPORT_OK ], );
 
@@ -57,6 +58,7 @@ my $bson_id_count : shared = 0;
 my $bson2_id_count  = 0;
 my $bson2_prev_time = 0;
 my $digest_cache;
+my $host_id = substr md5( hostname ), 0, 3;
 
 # Private functions
 my $_base64_char_set = sub {
@@ -155,10 +157,9 @@ my $_bsonid = sub {
    my $version = shift;
    my $now     = time;
    my $time    = $_bsonid_time->( $now, $version );
-   my $host    = substr md5( hostname ), 0, 3;
    my $pid     = pack 'n', $PID % 0xFFFF;
 
-   return $time.$host.$pid.$_bsonid_inc->( $now, $version );
+   return $time.$host_id.$pid.$_bsonid_inc->( $now, $version );
 };
 
 my $_find_cfg_in_inc = sub {
@@ -330,10 +331,6 @@ sub bson64id_time ($) {
    return unpack 'N', substr base64_decode_ns( $_[ 0 ] ), 2, 4;
 }
 
-sub build (&;$) {
-   my $code = shift; my $f = shift // sub {}; return sub { $code->( $f->() ) };
-}
-
 sub canonicalise ($;$) {
    my ($base, $relpath) = @_;
 
@@ -348,10 +345,6 @@ sub canonicalise ($;$) {
    return canonpath( untaint_path( catfile( $base, @relpath ) ) );
 }
 
-sub chain (;@) {
-   return (fold( sub { my ($x, $y) = @_; $x->$y })->( shift ))->( @_ );
-}
-
 sub class2appdir ($) {
    return lc distname( $_[ 0 ] );
 }
@@ -368,10 +361,6 @@ sub create_token (;$) {
    return digest( $_[ 0 ] // urandom() )->hexdigest;
 }
 
-sub curry (&$;@) {
-   my ($code, @args) = @_; return sub { $code->( @args, @_ ) };
-}
-
 sub cwdp () {
    return abs_path( curdir );
 }
@@ -531,18 +520,6 @@ sub first_char ($) {
    return substr $_[ 0 ], 0, 1;
 }
 
-sub fold (&) {
-   my $f = shift;
-
-   return sub (;$) {
-      my $x = shift;
-
-      return sub (;@) {
-         my $y = $x; $y = $f->( $y, shift ) while (@_); return $y;
-      }
-   }
-}
-
 sub fqdn (;$) {
    my $x = shift // hostname; return (gethostbyname( $x ))[ 0 ];
 }
@@ -701,10 +678,6 @@ sub prefix2class (;$) {
    return join '::', map { ucfirst } split m{ - }mx, my_prefix( $_[ 0 ] );
 }
 
-sub product (;@) {
-   return ((fold { $_[ 0 ] * $_[ 1 ] })->( 1 ))->( @_ );
-}
-
 sub socket_pair () {
    my $rdr = gensym; my $wtr = gensym;
 
@@ -738,10 +711,6 @@ sub sub_name (;$) {
    return (split m{ :: }mx, ((caller $frame)[ 3 ]) // 'main')[ -1 ];
 }
 
-sub sum (;@) {
-   return ((fold { $_[ 0 ] + $_[ 1 ] })->( 0 ))->( @_ );
-}
-
 sub symlink (;$$$) {
    my ($from, $to, $base) = @_;
 
@@ -841,6 +810,65 @@ sub zip (@) {
    my $p = @_ / 2; return @_[ map { $_, $_ + $p } 0 .. $p - 1 ];
 }
 
+# Function composition
+sub chain (;@) {
+   return (fold( sub { my ($x, $y) = @_; $x->$y } )->( shift ))->( @_ );
+}
+
+sub compose (&;$) { # Was called build
+   my ($f, $g) = @_; $g //= sub {}; return sub { $f->( $g->( @_ ) ) };
+}
+
+sub curry (&$;@) {
+   my ($f, @args) = @_; return sub { $f->( @args, @_ ) };
+}
+
+sub fold (&) {
+   my $f = shift;
+
+   return sub (;$) {
+      my $x = shift;
+
+      return sub (;@) {
+         my $y = $x; $y = $f->( $y, shift ) while (@_); return $y;
+      }
+   }
+}
+
+sub Y (&) {
+   my $f = shift; return sub { $f->( Y( $f ) )->( @_ ) };
+}
+
+sub factorial ($) {
+   return Y( sub (&) {
+      my $fac  = shift;
+
+      return sub ($) {
+         my $n = shift;
+
+         return $n < 2 ? 1 : $n * $fac->( $n - 1 ) } } )->( @_ );
+}
+
+sub fibonacci ($) {
+   return Y( sub {
+      my $fib  = shift;
+
+      return sub {
+         my $n = shift;
+
+         return $n == 0 ? 0
+              : $n == 1 ? 1
+                        : $fib->( $n - 1 ) + $fib->( $n - 2 ) } } )->( @_ );
+}
+
+sub product (;@) {
+   return ((fold { $_[ 0 ] * $_[ 1 ] })->( 1 ))->( @_ );
+}
+
+sub sum (;@) {
+   return ((fold { $_[ 0 ] + $_[ 1 ] })->( 0 ))->( @_ );
+}
+
 1;
 
 __END__
@@ -941,14 +969,6 @@ Base64 encoding is used to reduce the id length
 
 Returns the time the C<BSON64> id was generated as Unix time
 
-=head2 C<build>
-
-   $code_ref = build { }, $code_ref;
-
-Returns a code ref which when called returns the result of calling the block
-passing in the result of calling the optional code ref. Delays the calling
-of the input code ref until the output code ref is called
-
 =head2 C<canonicalise>
 
    $untainted_canonpath = canonicalise $base, $relpath;
@@ -957,13 +977,6 @@ Appends C<$relpath> to C<$base> using L<File::Spec::Functions>. The C<$base>
 and C<$relpath> arguments can be an array reference or a scalar. The return
 path is untainted and canonicalised
 
-=head2 C<chain>
-
-   $result = chain $sub1, $sub2, $sub3
-
-Call each sub in turn passing the returned value as the first argument to
-the next function call
-
 =head2 C<class2appdir>
 
    $appdir = class2appdir __PACKAGE__;
@@ -994,16 +1007,6 @@ Create a random string token using L</digest>. If C<$seed> is defined then add
 that to the digest, otherwise add some random data provided by a call to
 L</urandom>. Returns a hexadecimal string
 
-=head2 C<curry>
-
-   $curried_code_ref = curry $code_ref, @args;
-   $result = $curried_code_ref->( @more_args );
-
-Returns a subroutine reference which when called, calls and returns the
-initial code reference passing in the original argument list and the
-arguments from the curried call. Must be called with a code reference and
-at least one argument
-
 =head2 C<cwdp>
 
    $current_working_directory = cwdp;
@@ -1121,12 +1124,6 @@ Find absolute path to the source code for the given module
 
 Returns the first character of C<$string>
 
-=head2 C<fold>
-
-   *sum = fold { $a + $b } 0;
-
-Classic reduce function with optional base value
-
 =head2 C<fqdn>
 
    $domain_name = fqdn $hostname;
@@ -1275,12 +1272,6 @@ and defaults to I<right>
 Calls L</my_prefix> with the supplied argument, splits the result on dash,
 C<ucfirst>s the list and then C<join>s that with I<::>
 
-=head2 C<product>
-
-   $product = product 1, 2, 3, 4;
-
-Returns the product of the list of numbers
-
 =head2 C<socket_pair>
 
    ($reader, $writer) = @{ socket_pair };
@@ -1320,12 +1311,6 @@ Strips the leading "program_name: whitespace" from the passed argument
 
 Returns the name of the method that calls it
 
-=head2 C<sum>
-
-   $total = sum 1, 2, 3, 4;
-
-Adds the list of values
-
 =head2 C<symlink>
 
    $message = symlink $from, $to, $base;
@@ -1427,6 +1412,67 @@ would be a suitable value
 
 Zips two list of equal size together to form a hash
 
+=head2 C<chain>
+
+   $result = chain $sub1, $sub2, $sub3
+
+Call each sub in turn passing the returned value as the first argument to
+the next function call
+
+=head2 C<compose>
+
+   $code_ref = compose { }, $code_ref;
+
+Returns a code reference which when called returns the result of calling the
+block passing in the result of calling the optional code reference. Delays the
+calling of the input code reference until the output code reference is called
+
+=head2 C<curry>
+
+   $curried_code_ref = curry $code_ref, @args;
+   $result = $curried_code_ref->( @more_args );
+
+Returns a subroutine reference which when called, calls and returns the
+initial code reference passing in the original argument list and the
+arguments from the curried call. Must be called with a code reference and
+at least one argument
+
+=head2 C<fold>
+
+   *sum = fold { $a + $b } 0;
+
+Classic reduce function with optional base value
+
+=head2 C<Y>
+
+   $code_ref = Y( $code_ref );
+
+The Y-combinator function
+
+=head2 C<factorial>
+
+   $result = factorial $n;
+
+Calculates the factorial for the supplied integer
+
+=head2 C<fibonacci>
+
+   $result = fibonacci $n;
+
+Calculates the Fibonacci number for the supplied integer
+
+=head2 C<product>
+
+   $product = product 1, 2, 3, 4;
+
+Returns the product of the list of numbers
+
+=head2 C<sum>
+
+   $total = sum 1, 2, 3, 4;
+
+Adds the list of values
+
 =head1 Diagnostics
 
 None
