@@ -6,11 +6,13 @@ use File::Spec::Functions qw( catdir updir );
 use FindBin               qw( $Bin );
 use lib               catdir( $Bin, updir, 'lib' ), catdir( $Bin, 'lib' );
 
-use Test::More;
-use Test::Requires { version => 0.88 };
 use Module::Build;
 use Sys::Hostname;
 
+sub plan (;@) {
+   $_[ 0 ] eq 'skip_all' and print '1..0 # SKIP '.$_[ 1 ]."\n" and exit 0;
+}
+
 my ($builder, $host, $notes, $perl_ver);
 
 BEGIN {
@@ -19,16 +21,20 @@ BEGIN {
    $notes    = $builder ? $builder->notes : {};
    $perl_ver = $notes->{min_perl_version} || 5.008;
 
+   eval { require Test::Requires }; $@ and plan skip_all => 'No Test::Requires';
+
+   $Bin =~ m{ : .+ : }mx and plan skip_all => 'Two colons in $Bin path';
+
    if ($notes->{testing}) {
-      $Bin  =~ m{ : .+ : }mx and plan skip_all => 'Two colons in $Bin path';
-      $host =~ m{ \A davids-macbook }mx and
-         plan skip_all => 'Broken smoker 158a80fe-0a22-11e5-9d49-e60ed23c8333';
-      # TODO: Remove this when service is restored
-      plan skip_all => 'CPAN Testing down Aug 2015';
+      $host eq 'nwyf.bingosnet.co.uk' and plan skip_all =>
+         'Broken smoker 48aff258-06c0-11e5-a85a-e28fcaadd3a7';
+      $host =~ m{ \A davids-macbook }mx and plan skip_all =>
+         'Broken smoker 158a80fe-0a22-11e5-9d49-e60ed23c8333';
    }
 }
 
 use Test::Requires "${perl_ver}";
+use Test::Requires { version => 0.88 };
 
 sub import {
    strict->import;
